@@ -1,27 +1,26 @@
 test_that("OT_joint works", {
-
   data(tab_test)
-  tb_test     = tab_test[c(1:80,5001:5090),]
-  tb_test[,2] = factor(tb_test[,2])
-  tb_test[,3] = ordered(tb_test[,3])
+  tb_test <- tab_test[c(1:80, 5001:5090), ]
+  tb_test[, 2] <- factor(tb_test[, 2])
+  tb_test[, 3] <- ordered(tb_test[, 3])
 
-  test1 = OT_joint(tb_test, dist.choice = "M", percent.knn = 0.30, which.DB = "A", ordinal = 1:6, prox.X = 0.10, maxrelax = 0.4, lambda.reg = 0.1)
+  test1 <- OT_joint(tb_test, dist.choice = "M", percent.knn = 0.30, which.DB = "A", ordinal = 1:6, prox.X = 0.10, maxrelax = 0.4, lambda.reg = 0.1)
 
-  expect_that(test1,is_a("otres"))
-  expect_equal(length(test1),9)
+  expect_that(test1, is_a("otres"))
+  expect_equal(length(test1), 9)
 
-  expect_equal(sum(test1[[2]]),1)
+  expect_equal(sum(test1[[2]]), 1)
   # expect_equal(sum(test1[[3]]),1)
 
   # expect_equal(dim(test1[[2]]),dim(test1[[3]]))
-  expect_equal(nrow(test1[[2]]),length(levels(tb_test[,2])))
+  expect_equal(nrow(test1[[2]]), length(levels(tb_test[, 2])))
   # expect_equal(ncol(test1[[3]]),length(levels(tb_test[,3])))
 
-  expect_equal(ncol(test1[[4]]),ncol(tab_test)-2)
+  expect_equal(ncol(test1[[4]]), ncol(tab_test) - 2)
 
-  expect_that(test1[[5]],is_a("list"))
+  expect_that(test1[[5]], is_a("list"))
 
-  expect_identical(levels(test1[[8]][,ncol(test1[[8]])]),levels(tb_test[,3]))
+  expect_identical(levels(test1[[8]][, ncol(test1[[8]])]), levels(tb_test[, 3]))
   # expect_identical(levels(test1[[9]][,ncol(test1[[9]])]),levels(tb_test[,2]))
   # expect_equal(ncol(test1[[8]]),ncol(test1[[9]]))
 
@@ -44,7 +43,4 @@ test_that("OT_joint works", {
   # expect_equal(sum(test3[[2]]),1)
   # expect_equal(sum(test3[[3]]),1)
   # expect_equal(ncol(test3[[8]]),ncol(test3[[9]]))
-
-
-
 })
